/*
 *  noalign.cpp
 *  
 *
 *  Created by Pat Schloss on 2/19/09.
 *  Copyright 2009Schloss Lab UMASS Amherst. All rights reserved.
 *
 */

#include "alignment.hpp"
#include "noalign.hpp"

/**************************************************************************************************/

NoAlign::NoAlign(){	/*	do nothing	*/	}

/**************************************************************************************************/

NoAlign::~NoAlign(){	/*	do nothing	*/	}

/**************************************************************************************************/

void NoAlign::align(string A, string B, bool createBaseMap){	}

/**************************************************************************************************/
